package server

// REFACTOR: APP DEDICATED CODE
import (
	"net/http"

	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/middleware/cors"
)

var (
	defaultCORS = cors.New(cors.Config{
		AllowOrigins:     "*",
		AllowCredentials: true,
		AllowMethods:     "GET, POST, PATCH, PUT, DELETE, OPTIONS",
		AllowHeaders:     "Accept, Authorization, Content-Type, Vary, X-Request-Id",
	})
)

func SetupRouter(s *Server) {
	s.Base.Options("*", defaultCORS)

	s.Base.Get("/health", s.HealthHandler)
	s.Base.Get("/config", s.ConfigHandler)

	api := s.Base.Group("/api")
	v1 := api.Group("/v1")
	v1.Get("/basket", s.GetBasketHandler)
	v1.Get("/basket/:basketId/items", s.GetBasketItemsHandler)
	v1.Post("/checkout", s.CheckoutHandler)
}

func CORSPreflightMiddleware(c *fiber.Ctx) error {
	if string(c.Request().Header.Method()) == http.MethodOptions {
		c.Response().SetStatusCode(http.StatusOK)
		c.Next()
	}

	return c.Next()
}
